###+++++++++++++++++++++++++++++++++++++++++++++###
###### Code to implement MCMC algorithm to fit ####
######          Bayesian model for           ######
######  Booms et al. 2021 J. Raptor Research  ####
##########      By: Joe Eisaguirre       #########
###       Last edited 10 January 2021       #####
###++++++++++++++++++++++++++++++++++++++++++++###

dat=read.csv('GOEA_Availability_2016-18.csv')
dat$det=0
dat$det[dat$availability==1]=1
dat$det[1:2]=0 # two not detected in 2016
head(dat)

y=dat$availability
z=dat$det[dat$availability==1]
X=model.matrix(y~as.factor(dat$year))
X[,1]=0
X[,1][X[,2]==0&X[,3]==0]=1
W=model.matrix(z~as.factor(dat$year[dat$availability==1]))
W[,1]=0
W[,1][W[,2]==0&W[,3]==0]=1


## adjust counts 
U=round(c(1163,705,1020)*.86)

## load MCMC function
source('booms_et_al_jrr_2021_mcmc_rcode.R')

## priors
beta.mn=alpha.mn=rep(0,dim(X)[2])
beta.var=alpha.var=1.75^2
beta0.mn=alpha0.mn=0
beta0.var0=alpha0.var0=1.75^2
alpha0.mn=2 ## informative based on previous studies
alpha0.var=.5^2

n.mcmc=200000
beta.tune=.2
alpha.tune=1
a.g=10
b.g=.01

## chain 1
set.seed(23)
out1=logit.reg.mcmc(y,z,X,W,beta.mn,beta.var,beta0.mn,beta0.var0,beta.tune,
                   alpha.mn,alpha.var,alpha0.mn,alpha0.var0,alpha.tune,
                   U,a.g,b.g,lambda.tune=10,lam.var0=300^2,lam.mn=1000,n.mcmc=n.mcmc)
## chain 2
set.seed(13)
out2=logit.reg.mcmc(y,z,X,W,beta.mn,beta.var,beta0.mn,beta0.var0,beta.tune,
                   alpha.mn,alpha.var,alpha0.mn,alpha0.var0,alpha.tune,
                   U,a.g,b.g,lambda.tune=10,lam.var0=300^2,lam.mn=1000,n.mcmc=n.mcmc)
## chain 3
set.seed(133)
out3=logit.reg.mcmc(y,z,X,W,beta.mn,beta.var,beta0.mn,beta0.var0,beta.tune,
                    alpha.mn,alpha.var,alpha0.mn,alpha0.var0,alpha.tune,
                    U,a.g,b.g,lambda.tune=10,lam.var0=300^2,lam.mn=1000,n.mcmc=n.mcmc)

logit=function(p){
  log(p/(1-p))
}

logit.inv=function(z){
  exp(z)/(1+exp(z))
}

n.burn=100001
n.iter=n.mcmc

hist(logit.inv(out$beta0.save[1,]),typ='l')
plot(out1$beta.save[2,],typ='l')
lines(out2$beta.save[2,],col='red')
lines(out3$beta.save[3,],col='blue')

plot(out1$lambda.save[3,],typ='l')
lines(out2$lambda.save[1,],col='red')
plot(out2$N.save[2,],typ='l')
plot(out$lambda.save[2,],typ='l')
plot(out$N.save[2,],typ='l')

hist(out$N.save[1,],100,prob=TRUE)
lines(density(rgamma(50000,a.g,b.g)))

###
### summarize availability
###
## annual detection
mean(logit.inv(c(out1$beta.save[1,n.burn:n.iter],out2$beta.save[1,n.burn:n.iter],out3$beta.save[1,n.burn:n.iter])))
quantile(logit.inv(c(out1$beta.save[1,n.burn:n.iter],out2$beta.save[1,n.burn:n.iter],out3$beta.save[1,n.burn:n.iter])),prob=c(0.025,.975))
mean(logit.inv(c(out1$beta.save[2,n.burn:n.iter],out2$beta.save[2,n.burn:n.iter],out3$beta.save[2,n.burn:n.iter])))
quantile(logit.inv(c(out1$beta.save[2,n.burn:n.iter],out2$beta.save[2,n.burn:n.iter],out3$beta.save[2,n.burn:n.iter])),prob=c(0.025,.975))
mean(logit.inv(c(out1$beta.save[3,n.burn:n.iter],out2$beta.save[3,n.burn:n.iter],out3$beta.save[3,n.burn:n.iter])))
quantile(logit.inv(c(out1$beta.save[3,n.burn:n.iter],out2$beta.save[3,n.burn:n.iter],out3$beta.save[3,n.burn:n.iter])),prob=c(0.025,.975))

## pooled
mean(logit.inv(c(out1$beta0.save[1,n.burn:n.iter],out2$beta0.save[1,n.burn:n.iter],out3$beta0.save[1,n.burn:n.iter])))
quantile(logit.inv(c(out1$beta0.save[1,n.burn:n.iter],out2$beta0.save[1,n.burn:n.iter],out3$beta0.save[1,n.burn:n.iter])),prob=c(.025,.975))

###
### summarize detection
###
## pooled
mean(logit.inv(c(out1$alpha0.save[n.burn:n.iter],out2$alpha0.save[n.burn:n.iter],out3$alpha0.save[n.burn:n.iter])))
quantile(logit.inv(c(out1$alpha0.save[n.burn:n.iter],out2$alpha0.save[n.burn:n.iter],out3$alpha0.save[n.burn:n.iter])),prob=c(.025,.975))

###
### summarize abudance
###
## annual in study area
mean(c(out1$N.save[1,n.burn:n.iter],out2$N.save[1,n.burn:n.iter],out2$N.save[1,n.burn:n.iter]))
quantile(c(out1$N.save[1,n.burn:n.iter],out2$N.save[1,n.burn:n.iter],out2$N.save[1,n.burn:n.iter]),prob=c(.025,.975))
mean(c(out1$N.save[2,n.burn:n.iter],out2$N.save[2,n.burn:n.iter],out2$N.save[2,n.burn:n.iter]))
quantile(c(out1$N.save[2,n.burn:n.iter],out2$N.save[2,n.burn:n.iter],out2$N.save[2,n.burn:n.iter]),prob=c(.025,.975))
mean(c(out1$N.save[3,n.burn:n.iter],out2$N.save[3,n.burn:n.iter],out2$N.save[3,n.burn:n.iter]))
quantile(c(out1$N.save[3,n.burn:n.iter],out2$N.save[3,n.burn:n.iter],out2$N.save[3,n.burn:n.iter]),prob=c(.025,.975))

## range 1
mean(c(out1$N.tot.state.ml.save[1,n.burn:n.iter],out2$N.tot.state.ml.save[1,n.burn:n.iter],out3$N.tot.state.ml.save[1,n.burn:n.iter]),na.rm=TRUE)
quantile(c(out1$N.tot.state.ml.save[1,n.burn:n.iter],out2$N.tot.state.ml.save[1,n.burn:n.iter],out3$N.tot.state.ml.save[1,n.burn:n.iter]),prob=c(.025,.975),na.rm=TRUE)

## range 2
mean(c(out1$N.tot.state.l.save[1,n.burn:n.iter],out2$N.tot.state.l.save[1,n.burn:n.iter],out3$N.tot.state.l.save[1,n.burn:n.iter]),na.rm=TRUE)
quantile(c(out1$N.tot.state.l.save[1,n.burn:n.iter],out2$N.tot.state.l.save[1,n.burn:n.iter],out3$N.tot.state.l.save[1,n.burn:n.iter]),prob=c(.025,.975),na.rm=TRUE)

## pooled study area
mean(c(out1$N.p[1,n.burn:n.iter],out2$N.p[1,n.burn:n.iter],out3$N.p[1,n.burn:n.iter]))
quantile(c(out1$N.p[1,n.burn:n.iter],out2$N.p[1,n.burn:n.iter],out3$N.p[1,n.burn:n.iter]),prob=c(.025,.975))


###
### plot availability and detection
###

out.dat=data.frame(beta=c(out1$beta.save[1,n.burn:n.iter],out2$beta.save[1,n.burn:n.iter],out3$beta.save[1,n.burn:n.iter],
                          out1$beta.save[2,n.burn:n.iter],out2$beta.save[2,n.burn:n.iter],out3$beta.save[2,n.burn:n.iter],
                          out1$beta.save[3,n.burn:n.iter],out2$beta.save[3,n.burn:n.iter],out3$beta.save[3,n.burn:n.iter],
                          out1$beta0.save[1,n.burn:n.iter],out2$beta0.save[1,n.burn:n.iter],out3$beta0.save[1,n.burn:n.iter],
                          out1$alpha.save[1,n.burn:n.iter],out2$alpha.save[1,n.burn:n.iter],out3$alpha.save[1,n.burn:n.iter],
                          out1$alpha.save[2,n.burn:n.iter],out2$alpha.save[2,n.burn:n.iter],out3$alpha.save[2,n.burn:n.iter],
                          out1$alpha.save[3,n.burn:n.iter],out2$alpha.save[3,n.burn:n.iter],out3$alpha.save[3,n.burn:n.iter],
                          out1$alpha0.save[1,n.burn:n.iter],out2$alpha0.save[1,n.burn:n.iter],out3$alpha0.save[1,n.burn:n.iter]),
                   year=c(rep('2016',length(n.burn:n.iter)*3),
                          rep('2017',length(n.burn:n.iter)*3),
                          rep('2018',length(n.burn:n.iter)*3),
                          rep('Global',length(n.burn:n.iter)*3),
                          rep('2016',length(n.burn:n.iter)*3),
                          rep('2017',length(n.burn:n.iter)*3),
                          rep('2018',length(n.burn:n.iter)*3),
                          rep('Global',length(n.burn:n.iter)*3)),
                   parameter=c(rep('availability',length(n.burn:n.iter)*3*4),
                               rep('detection',length(n.burn:n.iter)*3*4)))
library(ggplot2)

ggplot(out.dat[out.dat$parameter=='availability',])+
  geom_histogram(aes(logit.inv(beta)),alpha=.5,position='identity',bins=100) +
  facet_grid(rows=vars(year),scales='free') +
  #xlab(expression(p[a]))
xlab('Availability')+ ylab('Relative Frequency')+
  theme_classic(base_size = 14)+
  theme(axis.text.y=element_blank(),
        axis.ticks.y=element_blank())
ggsave('goea_avail.png',height=7,width=5,units='in')
ggplot(out.dat[out.dat$parameter=='detection',])+
  geom_histogram(aes(logit.inv(beta)),alpha=.5,position='identity',bins=100) +
  facet_grid(rows=vars(year),scales='free') +
  #xlab(expression(p[d])) 
xlab('Detection')+ ylab('Relative Frequency')+
  xlim(0,1)+
  theme_classic(base_size = 14)+
  theme(axis.text.y=element_blank(),
        axis.ticks.y=element_blank())
ggsave('goea_detect.png',height=7,width=5,units='in')


###
### Plot abundance
###

abun.dat=data.frame(N=c(out1$N.save[1,n.burn:n.iter],out2$N.save[1,n.burn:n.iter],out3$N.save[1,n.burn:n.iter],
                        out1$N.save[2,n.burn:n.iter],out2$N.save[2,n.burn:n.iter],out3$N.save[2,n.burn:n.iter],
                        out1$N.save[3,n.burn:n.iter],out2$N.save[3,n.burn:n.iter],out3$N.save[3,n.burn:n.iter],
                        out1$N.p.save[1,n.burn:n.iter],out2$N.p.save[1,n.burn:n.iter],out3$N.p.save[1,n.burn:n.iter]),
                    year=c(rep('2016',length(n.burn:n.iter)*3),
                           rep('2017',length(n.burn:n.iter)*3),
                           rep('2018',length(n.burn:n.iter)*3),
                           rep('Global',length(n.burn:n.iter)*3)))
ggplot(abun.dat)+
  geom_histogram(aes(N),alpha=.5,position='identity',bins=100) +
  facet_grid(rows=vars(year),scales='free') +
  xlab('Southcentral Potential Breeder Abundance') + ylab('Relative Frequency')+
  #xlim(0,1)+
  geom_vline(xintercept=apply())
  theme_classic(base_size = 14)+
  theme(axis.text.y=element_blank(),
        axis.ticks.y=element_blank())
ggsave('goea_ad_abund.png',height=7,width=5,units='in')


abun.dat=data.frame(N=c(out1$N.tot.state.ml.save[1,n.burn:n.iter],out2$N.tot.state.ml.save[1,n.burn:n.iter],out3$N.tot.state.ml.save[1,n.burn:n.iter],
                        out1$N.tot.state.l.save[1,n.burn:n.iter],out2$N.tot.state.l.save[1,n.burn:n.iter],out3$N.tot.state.l.save[1,n.burn:n.iter]),
                    year=c(rep('range 1',length(n.burn:n.iter)*3),
                           rep('range 2',length(n.burn:n.iter)*3)))
ggplot(abun.dat)+
  geom_histogram(aes(N),alpha=.5,position='identity',bins=100) +
  facet_grid(rows=vars(year),scales='free') +
  xlab('Statewide total abundance') + ylab('relative frequency')+
  #xlim(0,1)+
  theme_classic(base_size = 14)+
  theme(axis.text.y=element_blank(),
        axis.ticks.y=element_blank())
ggsave('goea_tot_state_abund.png',height=5,width=5,units='in')
